Welcome to mirror list, hosted at ThFree Co, Russian Federation.

cygwin.com/git/newlib-cygwin.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorHans-Peter Nilsson <hp@axis.com>2000-11-28 00:52:56 +0300
committerHans-Peter Nilsson <hp@axis.com>2000-11-28 00:52:56 +0300
commit91797c6d8e6b2fbb4bb652aab2087ea6d7b09c00 (patch)
treefac8a910fc7e7c56dd7ec0de7531f9ead4dbd3f3 /include/elf/common.h
parentfe1c7fe7a6f2a3e422c1185e3126208ce48d434b (diff)
* common.h (e_machine numbers): Clarify comments to describe how
EM_* constants are assigned. Move EM_PJ from official section to ad-hoc section. (EM_CRIS): Correct comment to match official description. (EM_MMIX): Ditto.
Diffstat (limited to 'include/elf/common.h')
-rw-r--r--include/elf/common.h18
1 files changed, 12 insertions, 6 deletions
diff --git a/include/elf/common.h b/include/elf/common.h
index db7cad46f..13c17b0a1 100644
--- a/include/elf/common.h
+++ b/include/elf/common.h
@@ -90,7 +90,9 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
#define ET_LOPROC 0xFF00 /* Processor-specific */
#define ET_HIPROC 0xFFFF /* Processor-specific */
-/* Values for e_machine, which identifies the architecture. */
+/* Values for e_machine, which identifies the architecture. These numbers
+ are officially assigned by registry@sco.com. See below for a list of
+ ad-hoc numbers used during initial development. */
#define EM_NONE 0 /* No machine */
#define EM_M32 1 /* AT&T WE 32100 */
@@ -151,23 +153,27 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
#define EM_SVX 73 /* Silicon Graphics SVx */
#define EM_ST19 74 /* STMicroelectronics ST19 8-bit cpu */
#define EM_VAX 75 /* Digital VAX */
-#define EM_CRIS 76 /* Axis Communications 32-bit embedded cpu */
+#define EM_CRIS 76 /* Axis Communications 32-bit embedded processor */
#define EM_JAVELIN 77 /* Infineon Technologies 32-bit embedded cpu */
#define EM_FIREPATH 78 /* Element 14 64-bit DSP processor */
#define EM_ZSP 79 /* LSI Logic's 16-bit DSP processor */
-#define EM_MMIX 80 /* Donald Knuth's education 64-bit processor */
+#define EM_MMIX 80 /* Donald Knuth's educational 64-bit processor */
#define EM_HUANY 81 /* Harvard's machine-independent format */
#define EM_PRISM 82 /* SiTera Prism */
-#define EM_PJ 99 /* picoJava */
-
/* If it is necessary to assign new unofficial EM_* values, please pick large
random numbers (0x8523, 0xa7f2, etc.) to minimize the chances of collision
with official or non-GNU unofficial values.
NOTE: Do not just increment the most recent number by one.
Somebody else somewhere will do exactly the same thing, and you
- will have a collision. Instead, pick a random number. */
+ will have a collision. Instead, pick a random number.
+
+ Normally, each entity or maintainer responsible for a machine with an
+ unofficial e_machine number should eventually ask registry@sco.com for
+ an officially blessed number to be added to the list above. */
+
+#define EM_PJ 99 /* picoJava */
/* Cygnus PowerPC ELF backend. Written in the absence of an ABI. */
#define EM_CYGNUS_POWERPC 0x9025